%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 
% helipar.m
% Parameter des Helikoptermodells am IfA (Versuch 2.6). 
%
% Oliver Kaiser, Domenico Mignone, Sept. 1997
% Revision (after adding new hardware): Marc Osswald, Aug. 2009
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Allgemeine Modellparameter
r_V = 0.0298;  % Abstand zur horizontalen Achse
r_H = 0.0157;  % Abstand zum Schwerpunkt
r_G = 0.0953;  % Abstand des Gegengewichts
r_R = 0.1995;  % Abstand zum Tragrotor
r_S = 0.1743;  % Abstand zum Heckrotor
m_G = 1.19;    % Gesamtgewicht des Helikopters
g   = 9.81;    

% Parameter des Tragrotors
theta_R = 4.8e-4;  % Traegheitsmoment
c_muR   = 1e-5;    % Reibungskonstante
k_MR    = 1e-6;    % Propellerkonstante (Moment)
c_MR    = 0.028;   % Motorkonstante
c_GR    = 0.028;   % Generatorkonstante
R_R     = 0.9;     % Motorwiderstand
i_max   = 10;      % Maximaler Rotorstrom
u_max_phi   = 16;  % Maximale Rotorspannung

% Parameter des Heckrotors
theta_S = 3.2e-5;  % Traegheitsmoment
c_muS   = 1e-5;    % Reibungskonstante
k_MS    = 1e-7;    % Propellerkonstante (Moment)
c_MS    = 0.0091;  % Motorkonstante
c_GS    = 0.0091;  % Generatorkonstante
R_S     = 1.2;     % Motorwiderstand
i_max   = 10;      % Maximaler Rotorstrom
u_max_psi   = 8;   % Maximale Rotorspannung

% Parameter der horizontalen Achse
theta_H = 0.027;      % Traegheitsmoment
c_muH   = 5e-3;       % Reibungskonstante (Lagerreibung und Kabel)
k_FR    = 2.4e-5;     % Propellerkonstante (Kraft)
phi_maxH= 60*pi/180;  % Maximaler Winkel der horizontalen Achse
phi_minH= -phi_maxH;  % Minimaler Winkel der horizontalen Achse

% Parameter der vertikalen Achse
theta_V1 = 0.027;     % Traegheitsmoment
theta_V2 = 2.0e-4;    % Traegheitsmoment
theta_zyl= 1e-5;      % Traegheitsmoment
c_muV    = 5e-2;      % Reibungskonstante (Lagerreibung und Kabel)
k_FS     = 2.7e-6;      % Propellerkonstante (Kraft)
phi_maxV = 170*pi/180;% Maximaler Winkel der vertikalen Achse
phi_minV = -phi_maxV; % Minimaler Winkel der vertikalen Achse

% Sensoren
k_messH = 3.29;
k_messV = 3.36;

% Gleichgewichtslage
omega_R_b  =  202.0147;
omega_S_b  =  301.6782;
phi_FF     =  7.0331;
psi_FF     =  4.3432;



% Lineares Modell
a11 = -c_MR*c_GR/R_R - 2*k_MR*omega_R_b-c_muR;
a31 = -2*k_FR*r_R*omega_R_b;
a32 = m_G*g*r_V;
a33 = -c_muH;
a34 = -c_MS*c_GS/R_S;
a44 = -c_MS*c_GS/R_S - 2*k_MS*omega_S_b - c_muS;
a61 = c_MR*c_GR/R_R;
a62 = -k_FS*omega_S_b^2*r_V;
a64 = 2*k_FS*r_S*omega_S_b;
a66 = -c_muV;

A0 = [ a11   0   0   0   0   0 ;
         0   0   1   0   0   0 ;
       a31 a32 a33 a34   0   0 ;
         0   0   0 a44   0   0 ;
         0   0   0   0   0   1 ;
       a61 a62   0 a64   0 a66 ];

B0 = [c_MR/R_R        0 ;
             0        0 ;
             0 c_MS/R_S ;
             0 c_MS/R_S ;
             0        0 ;
     -c_MR/R_R        0 ];

THETA = diag([theta_R, 1, theta_H, theta_S, 1, theta_zyl+theta_V1+m_G*r_H^2]);

A = inv(THETA)*A0;
B = inv(THETA)*B0;
C = [0 k_messH 0 0 0 0;
     0 0 0 0 k_messV 0];
D = [0 0;
     0 0];

% -----------------
% Simulation Parameters
% -----------------

phistart_H = 0;
phistart_V = 0;